==> slackr_2.2.0.tar.gz: slackr/R/deprecated.r <==
# CAMEL CASE ALL THE THINGS (for legacy support)

#' Superseded by slackr_dev
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_dev
#' @export
#' @seealso \code{\link[slackr]{slackr_dev}}
#' @family Deprecated functions
dev.slackr <- function(...) {
  .Deprecated(new = 'slackr_dev')
  slackr_dev(...)
}

#' Superseded by slackr_dev
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_dev
#' @export
#' @seealso \code{\link[slackr]{slackr_dev}}
#' @family Deprecated functions
dev_slackr <- function(...) {
  .Deprecated(new = 'slackr_dev')
  slackr_dev(...)
}

#' Superseded by save_slackr
#'
#' deprecated
#'
#' @param ... arguments to pass to save_slackr
#' @export
#' @family Deprecated functions
#' @seealso \code{\link[slackr]{save_slackr}}
save.slackr <- function(...) {
  .Deprecated(new = 'save_slackr')
  save_slackr(...)
}

#' Superseded by slackr_bot
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_bot
#' @export
#' @family Deprecated functions
#' @seealso \code{\link[slackr]{slackr_bot}}
slackrBot <- function(...) {
  .Deprecated(new = 'slackr_bot')
  slackr_bot(...)
}

#' Superseded by slackr_chtrans
#'
#' deprecated
#' @rdname slackrChtrans
#' @param ... arguments to pass to slackr_chtrans
#' @export
#' @seealso \code{\link[slackr]{slackr_chtrans}}
#' @family Deprecated functions
slackrChtrans <- function(...) {
  .Deprecated(new = 'slackr_chtrans')
  slackr_chtrans(...)
}

#' Superseded by slackr_chtrans
#'
#' deprecated
#' @rdname slackrChtrans
#' @param ... arguments to pass to slackr_chtrans
#' @export
#' @seealso \code{\link[slackr]{slackr_chtrans}}
#' @family Deprecated functions
slackrChTrans <- function(...) {
  .Deprecated(new = 'slackr_chtrans')
  slackr_chtrans(...)
}

#' Superseded by slackr_channels
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_channels
#' @export
#' @family Deprecated functions
#' @seealso \code{\link[slackr]{slackr_channels}}
slackrChannels <- function(...) {
  .Deprecated(new = 'slackr_channels')
  slackr_channels(...)
}

#' Superseded by slackr_ims
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_ims
#' @export
#' @family Deprecated functions
#' @seealso \code{\link[slackr]{slackr_ims}}
slackrIms <- function(...) {
  .Deprecated(new = 'slackr_ims')
  slackr_ims(...)
}

#' Superseded by slackr_msg
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_msg
#' @export
#' @seealso \code{\link[slackr]{slackr_msg}}
#' @family Deprecated functions
slackrMsg <- function(...) {
  .Deprecated(new = 'slackr_msg')
  slackr_msg(...)
}

#' Superseded by slackr_setup
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_setup
#' @export
#' @family Deprecated functions
#' @seealso \code{\link[slackr]{slackr_setup}}
slackrSetup <- function(...) {
  .Deprecated(new = 'slackr_setup')
  slackr_setup(...)
}

#' Superseded by slackr_upload
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_upload
#' @export
#' @seealso \code{\link[slackr]{slackr_upload}}
#' @family Deprecated functions
slackrUpload <- function(...) {
  .Deprecated(new = 'slackr_upload')
  slackr_upload(...)
}

#' Superseded by slackr_users
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_users
#' @export
#' @seealso \code{\link[slackr]{slackr_users}}
#' @family Deprecated functions
slackrUsers <- function(...) {
  .Deprecated(new = 'slackr_users')
  slackr_users(...)
}

#' Superseded by text_slackr
#'
#' deprecated
#'
#' @param ... arguments to pass to text_slackr
#' @export
#' @seealso \code{\link[slackr]{slackr_msg}}
#' @family Deprecated functions
textSlackr <- function(...) {
  .Deprecated(new = 'slackr_msg')
  text_slackr(...)
}

==> slackr_2.3.0.tar.gz: slackr/R/deprecated.r <==
# CAMEL CASE ALL THE THINGS (for legacy support)

#' Superseded by slackr_dev
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_dev
#' @export
#' @seealso \code{\link[slackr]{slackr_dev}}
#' @family Deprecated functions
dev.slackr <- function(...) {
  .Deprecated(new = "slackr_dev")
  slackr_dev(...)
}

#' Superseded by slackr_dev
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_dev
#' @export
#' @seealso \code{\link[slackr]{slackr_dev}}
#' @family Deprecated functions
dev_slackr <- function(...) {
  .Deprecated(new = "slackr_dev")
  slackr_dev(...)
}

#' Superseded by save_slackr
#'
#' deprecated
#'
#' @param ... arguments to pass to save_slackr
#' @export
#' @family Deprecated functions
#' @seealso \code{\link[slackr]{save_slackr}}
save.slackr <- function(...) {
  .Deprecated(new = "save_slackr")
  save_slackr(...)
}

#' Superseded by slackr_save
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_save
#' @export
#' @seealso \code{\link[slackr]{slackr_save}}
#' @family Deprecated functions
save_slackr <- function(...) {
  .Deprecated(new = "slackr_save")
  slackr_save(...)
}

#' Superseded by slackr_bot
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_bot
#' @export
#' @family Deprecated functions
#' @seealso \code{\link[slackr]{slackr_bot}}
slackrBot <- function(...) {
  .Deprecated(new = "slackr_bot")
  slackr_bot(...)
}

#' Superseded by slackr_chtrans
#'
#' deprecated
#' @rdname slackrChtrans
#' @param ... arguments to pass to slackr_chtrans
#' @export
#' @seealso \code{\link[slackr]{slackr_chtrans}}
#' @family Deprecated functions
slackrChtrans <- function(...) {
  .Deprecated(new = "slackr_chtrans")
  slackr_chtrans(...)
}

#' Superseded by slackr_chtrans
#'
#' deprecated
#' @rdname slackrChtrans
#' @param ... arguments to pass to slackr_chtrans
#' @export
#' @seealso \code{\link[slackr]{slackr_chtrans}}
#' @family Deprecated functions
slackrChTrans <- function(...) {
  .Deprecated(new = "slackr_chtrans")
  slackr_chtrans(...)
}

#' Superseded by slackr_channels
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_channels
#' @export
#' @family Deprecated functions
#' @seealso \code{\link[slackr]{slackr_channels}}
slackrChannels <- function(...) {
  .Deprecated(new = "slackr_channels")
  slackr_channels(...)
}

#' Superseded by slackr_ims
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_ims
#' @export
#' @family Deprecated functions
#' @seealso \code{\link[slackr]{slackr_ims}}
slackrIms <- function(...) {
  .Deprecated(new = "slackr_ims")
  slackr_ims(...)
}

#' Superseded by slackr_msg
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_msg
#' @export
#' @seealso \code{\link[slackr]{slackr_msg}}
#' @family Deprecated functions
slackrMsg <- function(...) {
  .Deprecated(new = "slackr_msg")
  slackr_msg(...)
}

#' Superseded by slackr_setup
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_setup
#' @export
#' @family Deprecated functions
#' @seealso \code{\link[slackr]{slackr_setup}}
slackrSetup <- function(...) {
  .Deprecated(new = "slackr_setup")
  slackr_setup(...)
}

#' Superseded by slackr_upload
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_upload
#' @export
#' @seealso \code{\link[slackr]{slackr_upload}}
#' @family Deprecated functions
slackrUpload <- function(...) {
  .Deprecated(new = "slackr_upload")
  slackr_upload(...)
}

#' Superseded by slackr_users
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_users
#' @export
#' @seealso \code{\link[slackr]{slackr_users}}
#' @family Deprecated functions
slackrUsers <- function(...) {
  .Deprecated(new = "slackr_users")
  slackr_users(...)
}

#' Superseded by text_slackr
#'
#' deprecated
#'
#' @param ... arguments to pass to text_slackr
#' @export
#' @seealso \code{\link[slackr]{slackr_msg}}
#' @family Deprecated functions
textSlackr <- function(...) {
  .Deprecated(new = "slackr_msg")
  text_slackr(...)
}

#' Superseded by slackr_tex
#'
#' deprecated
#'
#' @param ... arguments to pass to slackr_tex
#' @seealso \code{\link[slackr]{slackr_tex}}
#' @family Deprecated functions
tex_slackr <- function(...) {
  .Deprecated(new = 'slackr_tex')
  slackr_tex(...)
}
